@@ -148,9 +148,9 @@ class Worker:
     # 2. Large blob (more than segment_limit) is being processed. Partial result is written to blob_0. Result of blob splitted into segment_list size parts and enqueued.
     # 3. Parent task (with child_task_partition field). We poll child tasks. Record progress. If child task fails -> parent fails as well.
     def _process_blob(self, request_id, request_entity, func):
-        blob_name, params, child_task_partition, retry_count = self._read_metadata(request_entity)
-        if child_task_partition:
-            self._poll_child_tasks(request_entity, request_id, child_task_partition)
+        blob_name, params, child_tasks_partition, retry_count = self._read_metadata(request_entity)
+        if child_tasks_partition:
+            self._poll_child_tasks(request_entity, request_id, child_tasks_partition)
             return
 
         try:
@@ -262,7 +262,7 @@ class Worker:
         params = None
         if 'Parameters' in request_entity:
             params = json.loads(request_entity['Parameters'])
-        offset = 0
+        child_tasks_partition = 0
         if 'ChildTasksPartition' in request_entity:
             child_tasks_partition = request_entity['ChildTasksPartition']
         retry_count = 0
